import os

basedir = os.path.abspath(os.path.dirname(__file__))

class Config(object):
    SECRET_KEY = f"{os.getenv('SECRET_KEY')}"
    RECAPTCHA_PUBLIC_KEY = f"{os.getenv('RECAPTCHA_PUBLIC_KEY')}"
    RECAPTCHA_PRIVATE_KEY = f"{os.getenv('RECAPTCHA_PRIVATE_KEY')}"
    SQLALCHEMY_DATABASE_URI = os.getenv("DATABASE_URL", "sqlite://")
    SQLALCHEMY_TRACK_MODIFICATIONS = False
    STATIC_FOLDER = f"{os.getenv('APP_HOME')}/forest/static"
    MEDIA_FOLDER = f"{os.getenv('APP_HOME')}/forest/media"
    ADMIN_PREFIX = "fadmin"
    MAIL_SENDER = f"{os.getenv('MAIL_SENDER')}"
    MAIL_SERVER = f"{os.getenv('MAIL_SERVER')}"
    MAIL_USERNAME = f"{os.getenv('MAIL_USERNAME')}"
    MAIL_PASSWORD = f"{os.getenv('MAIL_PASSWORD')}"
    MAIL_PORT = f"{os.getenv('MAIL_PORT')}"
    MAIL_SUBJECT_PREFIX = f"{os.getenv('MAIL_SUBJECT_PREFIX')}"
    MAIL_USE_TLS = f"{os.getenv('MAIL_USE_TLS')}"
    ADMIN_MAIL = f"{os.getenv('ADMIN_MAIL')}"
    ITEMS_PER_PAGE = f"{os.getenv('ITEMS_PER_PAGE')}"
    OAUTH2_PROVIDERS = {
    # Google OAuth 2.0 documentation:
    # https://developers.google.com/identity/protocols/oauth2/web-server#httprest
    'google': {
        'client_id': os.environ.get('GOOGLE_CLIENT_ID'),
        'client_secret': os.environ.get('GOOGLE_CLIENT_SECRET'),
        'authorize_url': 'https://accounts.google.com/o/oauth2/auth',
        'token_url': 'https://accounts.google.com/o/oauth2/token',
        'userinfo': {
            'url': 'https://www.googleapis.com/oauth2/v3/userinfo',
            'email': lambda json: json['email'],
        },
        'scopes': ['https://www.googleapis.com/auth/userinfo.email'],
    },

    # GitHub OAuth 2.0 documentation:
    # https://docs.github.com/en/apps/oauth-apps/building-oauth-apps/authorizing-oauth-apps
    'github': {
        'client_id': os.environ.get('GITHUB_CLIENT_ID'),
        'client_secret': os.environ.get('GITHUB_CLIENT_SECRET'),
        'authorize_url': 'https://github.com/login/oauth/authorize',
        'token_url': 'https://github.com/login/oauth/access_token',
        'userinfo': {
            'url': 'https://api.github.com/user/emails',
            'email': lambda json: json[0]['email'],
        },
        'scopes': ['user:email'],
    }
    }
